%% Characteristics of Inventory- Urban/Rural Breakdown
% Alisa White, May 8th 2018

%Note:
%The purpose of this script is to break out the infrastructure totals into
%urban and rural area and (when applicable) by voltage class for costing
%and stressor response purposes

%Import Infrastructure Inventory

load([home.outputs '\MAT Files\Infrastructure_Inventory']);
inventory=data;
clear data

%Some more names/nums
names.voltageSub={'subtrans34','subtrans46','substrans69','low','medium','high'};
names.voltageTr={'1','2','3','4','5'};
names.poleH=xlsread([home.inputs '\Maps and Keys\HSIP Shapefiles\Electric_Substations\' ...
    'SubsUrbanRural.xlsx'],'PercentsByCounty','B3:G3111');
names.geo={'urban','rural'};
names.totalyrs=[2006:2100];
names.classes={'1','2','3','4','5','6','7','8','9','H1','H2','H3','H4','H5','H6'};
names.heights=xlsread([home.inputs '\Maps and Keys\Vermont Data\VT_Green_Mountain_Power_Pole_Data\Urban_Power_Poles.xlsx'], ...
    'ClassbyHeight','B50:B71');

%Nums
num.voltageSub=length(names.voltageSub);
num.voltageTr=length(names.voltageTr);
num.geo=length(names.geo);
num.totalyrs=length(names.totalyrs);
num.classes=length(names.classes);
num.heights=length(names.heights);

%% Substation Characteristics (Urban v Rural)

% Part 1: Substation Voltage
%Breakdown into % low, medium, high voltage substations by county (across
%urban and rural areas) - Total % across each county (6 columns) should
%sum to approximately 1

data=xlsread([home.inputs '\Maps and Keys\HSIP Shapefiles\Electric_Substations\' ...
    'SubsUrbanRural.xlsx'],'PercentsByCounty','B3:M3111');

subvolt=nan(num.counties,num.totalyrs,num.policy,num.models,num.rcps,num.voltageSub,num.geo);
for county=1:num.counties
    for volt=1:num.voltageSub
        subvolt(county,:,:,:,:,volt,1)=inventory(county,1,:,:,:,:).*data(county,volt);
        subvolt(county,:,:,:,:,volt,2)=inventory(county,1,:,:,:,:).*data(county,volt+3);
    end
end

% Part 2: # of Substation Transformers
%Average number of transformers per substation for subtrans 34, subtrans 36
%subtran69 and low, medium, high voltage classes

avtransf=[0.21,0.31,0.17,0.48,1.56,14.26]; %From FERC Form 1
for volt=1:num.voltageSub
    subtransf=subvolt(:,:,:,:,:,volt,:).*avtransf(volt,:);
end

%NOTE: The average number of transformers overall in FERC Form 1 is 2.89
%per substation with a median of 1 per substation

clear data
%% Transmission Line Characteristics (Urban v Rural)

% Part 1: Transmission Line Voltage
data=xlsread([home.inputs '\Maps and Keys\HSIP Shapefiles\Electric_Power_Transmission_Lines\' ...
    'UrbanRuralVoltMiles.xlsx'],'Percent_By_Type','B3:K3111');

transvolt=nan(num.counties,num.totalyrs,num.policy,num.models,num.rcps,num.voltageTr,num.geo);
for county=1:num.counties
    for volt=1:num.voltageTr
        transvolt(county,:,:,:,:,volt,1)=inventory(county,2,:,:,:,:).*data(county,volt);
        transvolt(county,:,:,:,:,volt,2)=inventory(county,2,:,:,:,:).*data(county,volt+5);
    end
end

clear data

%% Distribution Poles Class and Height

%STEP 1: First, generate number of urban poles and rural poles for each county
%based on % urban versus % rural population 

%Percent of population that is urban by county
urbanrural=xlsread([home.inputs '\Data Files\InfrastructureInventoryFull.xlsx'], ...
    'Data_Not_ESRT','G2:G3110');

%Distance between poles urban v rural (in miles)
dist=[0.02172,0.03040];

distributionpoles=nan(num.counties,num.totalyrs,num.policy,num.models,num.rcps,num.geo);
for county=1:num.counties
    distributionpoles(county,:,:,:,:,1)=bsxfun(@minus,inventory(county,4,:,:,:,:),(inventory(county,3,:,:,:,:).*urbanrural(county,:).*dist(:,1)));
    distributionpoles(county,:,:,:,:,2)=bsxfun(@minus,inventory(county,4,:,:,:,:),(inventory(county,3,:,:,:,:).*(1-urbanrural(county,:)).*dist(:,2)));
end

%Step 2: Import tables for urban and rural area of percent of poles in each
%height-class combination

urbanclassheight=xlsread([home.inputs '\Maps and Keys\Vermont Data\VT_Green_Mountain_Power_Pole_Data\Urban_Power_Poles.xlsx'], ...
    'ClassbyHeight','B50:P71');
ruralclassheight=xlsread([home.inputs '\Maps and Keys\Vermont Data\VT_Green_Mountain_Power_Pole_Data\Rural_Power_Poles.xlsx'], ...
    'ClassbyHeight','B55:P76');

%NOTES: the two tables for class height will have to be applied within a
%for loop as the dimensions of the inventory become too large otherwise

%Step 3:Voltage (in volts) associated with height of power pole
%First column is height in ft, second column is voltage in volts
voltageheight=xlsread([home.inputs '\Maps and Keys\Vermont Data\VT_Green_Mountain_Power_Pole_Data\Voltage based on height.xlsx'], ...
    'Voltage','B2:C6');


%% 



