%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

%% EPA Grid Reliability Infrastructure Inventory Master Code 
% Alisa White, Research Analyst 
% Industrial Economics, Inc.

%Note: The supplementary material includes Steps 1, 2, 3, and 5. The
%mapping code is not included as it requires third party code.

%Note: We do not include the county level infrastructure inventory input 
%to this code due to data privacy requirements. In order to compile the 
%2015 inventory, we purchased the 2017 UDI Directory of Electric Power 
%Producers and Distributors from S&P Global Platts. Please contact them 
%for further information about this database.

clear 
clc

addpath(genpath('L:\01 Data\src'));

%% Step 1: Setup
% The setup includes lists of important names and numbers for the analysis
cd('L:\02 Projects\EPA Grid Reliability II\04 Data and Analysis\01 Infrastructure Inventory\src');
Inventory_Setup

%% Step 2: Inventory Projection
% This code takes the inventory for 2015 and projects it out through 2099
% as well as backcasting the inventory to 2008.

switches.proj=false;

if switches.proj
    Inventory_Projection_v2
end


%% Step 3: Inventory QC
% This code quality checks (QC) the inventory projection to ensure it was
% done correctly - includes maps and tables

switches.QC=false;
if switches.QC
Inventory_QC
end

%% Step 4: Manuscript Maps
%This code creates the maps we use in the manuscript
%Please note it has third party code, "map_Poly" and IEc created code
%called "map_Poly_panel"

switches.Maps=false;
if switches.Maps
    Inventory_ManuMaps_v3
end

%% Step 5: Inventory Spreadsheets
%This code creates spreadsheets for each stressor-response and costs for
%each gcm x rcp x era combination. Eras: 2030, 2050, 2070, 2090.
switches.spread=false;
if switches.spread
    Inventory_Spreadsheets
end

