%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

%{
clear
temp = repmat((10:10:50)',1,365);
tran = rand(size(temp))*10;
loadFrac = linspace(.9,1,10);
for i = 1:10
[life_loss,temph] = Temp_DistTransformerLOL(temp,tran,loadFrac(i));
life(:,i) = sum(life_loss,2);
end
xx = (1-bsxfun(@rdivide,life,life(:,end)))*100;
plot((1-loadFrac)*100,xx')
legend({'10' '20' '30' '40' '50'})
xlabel('Load Reduction (%)')
ylabel('Loss of Life Reduction (%)')
%}

function [life_loss,temph] = Temp_DistTransformerLOL(temp,tran,loadFrac)

A = -11.269;
B = 6328.8;
t = 1;
n = 0.8;
Tr = 3.5;
R = 2.7;
theta_wr = 65;
theta_or = 55;

num.loc = size(temp,1);
num.day = size(temp,2);

if nargin <= 2
  loadFrac = 1;
end

% construct hourly temperature
temph = nan(num.loc,num.day*24);
for loc = 1:size(temp,1)
  temph(loc,:) = reshape(bsxfun(@times,repmat(tran(loc,:),24,1),sin(pi*((1:24)-9.5)/12)'),1,[])+...
    reshape(repmat(temp(loc,:),24,1),1,[]);
end

% Load hourly load
xx = dlmread('k_mult.csv');
K = repmat(xx(:,2)',num.loc,1) .* loadFrac;

if num.day == 366
  K(:,end+1:end+24) = K(:,end-23:end);
end

%% Calculation of theta_g

% Step 1. Calculate values not dependent on k
% 1a Calculate theta_gr

theta_gr = theta_wr - theta_or + 15;

% 1b Calculate theta_gu (dependent on k)
theta_gu = K.^(2*n).*theta_gr;
theta_gi = [theta_gu(:,2:end) theta_gu(:,1)];

% Step 2. Calculate theta_g (varies based on initial and final values of theta_gu)
theta_g = (theta_gu - theta_gi) .* (1 - exp(-t/Tr)) + theta_gi;

%% Calculation of theta_o
% Step 1. Calculate values not dependent on k
% 1a Calculate theta_ou

theta_ou = (((K.^2)*R + 1)/(R+1)).^n * theta_or;
% 1b Calculate theta_oi (lag of theta_ou) [2,3,4,5,6,7,8]
theta_oi = [theta_ou(:,2:end) theta_ou(:,1)];%:= shift(theta_ou, 1L, type="lag")]

% 1b Calculate theta_o
theta_o = (theta_ou - theta_oi) .* (1 - exp(-t/Tr)) + theta_oi;

% Use first theta_g and theta_o (replace NAs)
theta_gi(1) = theta_gi(2);
theta_g(1) = theta_g(2);
theta_oi(1) = theta_oi(2);
theta_o(1) = theta_o(2);

% Define LOL function
life_loss = 100.*t.*(10.^(-(A+B./(273 + theta_o(:,1:end) + theta_g(:,1:end) + temph))));



