%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

%*********************************
% Estimates reduction in large(power) transformer lifespan given mean change 
%     in annual temperature. 
% Chas Fant June 2018
% 
% Based on Gao et al. 2017
% Temperatures above 30 reduce capacity by 0.7% for each degree above 30
% 
%*********************************
% 
% capfrac = Temp_PowerTransCap(temp,tran) 
% 
% INPUT 
%   delT: column vector of mean annual temperature (C) change where 
%           rows are locations (1,locs)
% 
% OUTPUT
%   lifespan: annual lifespan in years
% 
% Example / Test
% 
%{
  delT = (rand(3e3,1)-.2)*4;
  lifespan = Temp_PowerTransLifespan(delT);
  plot(delT,lifespan,'k.')
 %}

function LOL = Temp_PowerTransLifespan(delT)

% default values
DPstart = 1000;
DPend = 200;
A = 2e8;
T0 = 82+273.15; % design standard transformer heat at peak

T = T0 + delT;
lifespan = (((1/DPend)-(1/DPstart))/(A*24*365))*exp(13350./T);

lifespan0 = (((1/DPend)-(1/DPstart))/(A*24*365))*exp(13350./T0);

LOL = lifespan0 - lifespan;

end

