%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

% temperature and transmission line capacity
% 
% 
% INPUT
%     Tamb: ambient temperature (deg C, use daily high)
%     Voltage: nominal volage (kV) of cable
%     Tcond: conductor temperature to avoid sag
% 
% OUTPUT
%     capFrac: annual maximum capacity reduction
%     I: Ampacity    
% 
% 
% EXAMPLE
%{
Tamb = 0:1:60;
Tcond = 75;
figure(34), clf, hold on
for i = 1:61
[capFrac(i,:) adapt(i,:) adapt2(i,:)] = Temp_TransLine_Capacity(Tamb(i));
end
subplot(3,1,1)
plot(Tamb,capFrac*100,'k.')
subplot(3,1,2)
plot(Tamb,adapt*100,'k.')
subplot(3,1,3)
plot(Tamb,adapt2*100,'k.')
%}

function [capFrac, adaptACSS, adaptACCC] = Temp_TransLine_Capacity(Tamb)

Tcond = 75;
TcondACCC = 180;
TcondACSS = 250;

voltages = [14 69 115 230 345 500]; N = length(voltages);
Amp25 = nan(1,5);
Amp = nan(size(Tamb,1),N,size(Tamb,2));
AmpAdaptACCC = Amp;
AmpAdaptACSS = Amp;
for i = 1:N
  Amp25(i) = Temp_TransLine_Ampacity(25,voltages(i),Tcond,'ASCR');
  Amp(:,i,:) = Temp_TransLine_Ampacity(Tamb,voltages(i),Tcond,'ASCR');
  AmpAdaptACCC(:,i,:) = Temp_TransLine_Ampacity(Tamb,voltages(i),TcondACCC,'ACCC');
  AmpAdaptACSS(:,i,:) = Temp_TransLine_Ampacity(Tamb,voltages(i),TcondACSS,'ACSS');
end

% Difference from ASCR @ 25C ambient
capFrac = 1 - squeeze(max(bsxfun(@rdivide,Amp,Amp25),[],3));
adaptACCC = 1 - squeeze(max(bsxfun(@rdivide,AmpAdaptACCC,Amp25),[],3));
adaptACSS = 1 - squeeze(max(bsxfun(@rdivide,AmpAdaptACSS,Amp25),[],3));

end






