%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

% loops

addpath fcn

% output preallocation
xx = nan(num.cty,num.yearsFut,num.clims);
PowerTransLife1 = xx;
PowerTransCapfrac = xx;
poleDecayRate = xx;
TransLineCapfrac = nan([size(xx) num.volts]);
TransLineCapfracACSS = nan([size(xx) num.volts]);
TransLineCapfracACCC = nan([size(xx) num.volts]);
DistTransformerLossLife = xx;
DistTransformerCapFrac = xx;
% gcm loop
for clim = 1:num.clims
  CLIM = names.clims{clim};
  
      % load climate
      switch CLIM
        case 'HIST'
          
          % loading historical
          load([home.climate 'Observed Baseline\LOCA_ObsBaseline_county_pr.mat'])
          names.years = names.yearsHist;
          num.years = num.yearsHist;
          ihistYr = ismember(1950:2013,names.yearsHist);
          Cday = nan(num.cty,366,num.years,3);
          Cday(:,:,:,1) = data(:,:,ihistYr);
          load([home.climate 'Observed Baseline\LOCA_ObsBaseline_county_tasmax.mat'])
          Cday(:,:,:,2) = data(:,:,ihistYr);
          load([home.climate 'Observed Baseline\LOCA_ObsBaseline_county_tasmin.mat'])
          Cday(:,:,:,3) = data(:,:,ihistYr);
          
          % T annual mean used for substation lifespan
          TmeanBase = nanmean(nanmean((Cday(:,:,:,2) + Cday(:,:,:,3)) ./ 2, 3),2);

        otherwise
          
          % loading projection
          load([home.climate 'Projections\LOCA_Proj_county_' CLIM '_pr.mat'])
          names.years = names.yearsFut;
          num.years = size(data,3);
          Cday = nan(num.cty,366,num.years,3);
          Cday(:,:,:,1) = data;
          load([home.climate 'Projections\LOCA_Proj_county_' CLIM '_tasmax.mat'])
          Cday(:,:,:,2) = data;
          load([home.climate 'Projections\LOCA_Proj_county_' CLIM '_tasmin.mat'])
          Cday(:,:,:,3) = data;
          num.years = size(Cday,3);
          baseLOL = nanmean(DistTransformerLossLife(:,1:num.yearsHist,1),2); % for dist transformers
          
      end
      
      
      poleCount = ones(num.cty,50);
      rmat = nan(num.cty,num.years);
    % year loop
    for year = 1:num.years
      
%     dims:  {'pr' 'tmax' 'tmin'}
      temp = (Cday(:,:,year,2) + Cday(:,:,year,3)) ./ 2;
      tmax = Cday(:,:,year,2);
      tran = Cday(:,:,year,2) - Cday(:,:,year,3);
      prec = Cday(:,:,year,1);
      
      % remove leap year
      if mean(isnan(temp(:,366))) == 1
        temp(:,366) = [];
        prec(:,366) = [];
        tran(:,366) = [];
        tmax(:,366) = [];
      end
      
      % monthly
      tempmon = nan(num.cty,12);
      precmon = tempmon;
      ind = 0;
      for m = 1:12
        ind = max(ind) + (1:eomday(names.years(year),m));
        tempmon(:,m) = mean(temp(:,ind,:),2);
        precmon(:,m) = sum(prec(:,ind,:),2);
      end
      
      %-- Timber pole lifespan
      class = 2; % assume durability class 3
      [poleDecayRate(:,year,clim)] = ...
                        TandP_WoodPoleLifespan(tempmon,precmon,class);
      
      %-- Substation lifespan
      delT = nanmean(temp,2) - TmeanBase;
      PowerTransLife1(:,year,clim) = Temp_PowerTransLifespan(delT);
      
      %-- substation capacity
      capFracSub = Temp_PowerTransCap(tmax);
      
      %-- transmission line capacity
      [capFracAmp, capFracAmpACSS, capFracAmpACCC] = Temp_TransLine_Capacity(tmax);
      
      %-- distribution loss of life
      life_loss = Temp_DistTransformerLOL(temp,tran);
      DistTransformerLossLife(:,year,clim) = sum(life_loss,2);
      
      %-- distribution capacity
      currLOL = DistTransformerLossLife(:,year,clim);
      if strcmp(CLIM,'HIST')
%         [~,LOLtab(:,:,year)] = Temp_DistTransformerCap([],currLOL,temp,tran);
      else
        DistTransformerCapFrac(:,year,clim) = Temp_DistTransformerCap(baseLOL,currLOL,temp,tran);
      end
      
      % make sure capacities are always increasing
      % grab max so far if year ~= 1
      if year==1
        if strcmp(CLIM,'HIST')
          maxcap = capFracSub;
          maxAmp = capFracAmp;
          maxAmpACSS = capFracAmpACSS;
          maxAmpACCC = capFracAmpACCC;
%           maxcapD = capFracD;
        else
          maxcap = maxcapBase;
          maxAmp = maxAmpBase;
          maxAmpACSS = maxAmpBaseACSS;
          maxAmpACCC = maxAmpBaseACCC;
%           maxcapD = maxcapDBase;
        end
      else
        maxcap = max(PowerTransCapfrac(:,year-1,clim),capFracSub);
        maxAmp = max(squeeze(TransLineCapfrac(:,year-1,clim,:)),capFracAmp);
        maxAmpACSS = max(squeeze(TransLineCapfracACSS(:,year-1,clim,:)),capFracAmpACSS);
        maxAmpACCC = max(squeeze(TransLineCapfracACCC(:,year-1,clim,:)),capFracAmpACCC);
%         maxcapD = max(DistTransformerCapFrac(:,year-1,clim),capFracD);
      end
      PowerTransCapfrac(:,year,clim) = maxcap;
      TransLineCapfrac(:,year,clim,:) = maxAmp;
      TransLineCapfracACSS(:,year,clim,:) = maxAmpACSS;
      TransLineCapfracACCC(:,year,clim,:) = maxAmpACCC;
%       DistTransformerCapFrac(:,year,clim) = maxcapD;
      
    end % years
    
    fprintf('%d. %s | %0.2f min \n',clim,CLIM,toc/60)
    
    clear Cday
    
    if strcmp(CLIM,'HIST')
      maxcapBase = maxcap;
      maxAmpBase = maxAmp;
      maxAmpBaseACSS = maxAmpACSS;
      maxAmpBaseACCC = maxAmpACCC;
    end
    
end % climate

save([home.output 'intermediate\SR_loops.mat'],...
  'DistTransformerLossLife', 'PowerTransLife1', 'poleDecayRate', ...
  'PowerTransCapfrac', 'TransLineCapfrac', 'DistTransformerCapFrac','TransLineCapfracACCC','TransLineCapfracACSS')
