%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

load([home.output 'intermediate/SR_loops.mat'])

% % Lightning
load([home.input 'Distribution_Failures_2015_Inventory.mat']);
load([home.input 'Transmission_Permanent_Lightning_Failures_Cost_2015_Inventory.mat']);
DistLineLightning = reshape(dist_failures_2015_inventory(:,1:94,:,:),[num.cty num.yearsFut 10]);
TransLineLightningRepair = reshape(trans_failures_2015_perm_cost(:,1:94,:,:),[num.cty num.yearsFut 10]);

% wildfires
load([home.input 'wildfiresTransLinesBurned.mat'],'wfLineMilesBurned')
% make first 2 years
wfBase = nanmean(wfLineMilesBurned(:,1:20,1),2);
wfLineMilesBurned(:,1:end+2,2:end) = cat(2,repmat(wfBase,[1 2 10]),wfLineMilesBurned(:,:,2:end));

% trees
load([home.input 'LiveAboveGrTree.mat'],'TreeTrimCosts')
TreeTrimCosts = TreeTrimCosts * 1.0676; % convert from 2012 $ to 2017 $

% SLR and Storm Surge
scens = {'313' '306'
          4     7};
load([home.input 'SLRSS_Subs.mat'])
SubSLR = zeros(num.cty,num.yearsFut,2,4,3);
SubStormSurge = zeros(num.cty,num.yearsFut,2,4,3);
subCost = [10e6 10e6 20e6 50e6];
% armoring
InitCost.BackBay = 500;
InitCost.OpenOcean = 1000;
OaMrate.BackBay = 4;
OaMrate.OpenOcean = 10;
lengthshore = 525;
for rcp = 1:2
  scen = scens{1,rcp};
  sceni = scens{2,rcp};
for cty = 1:num.cty
  id = sprintf('%05d',names.cty(cty));
  ind = strcmp(Substations.County_FIP,id);
  if sum(ind)~=0
    csubs = Substations(ind,:);
    % inundation
    inds = find(strcmp(csubs.(['Decision_' scen]),'Abandon'));
    for i = 1:length(inds)
      ys = csubs.(['YearInundation_' scen])(inds(i));
      yi = ismember(names.yearsFut,ys);
      sizet = csubs.MAX_VOLT(inds(i));
      sizei = findClosestInd([-999999 115 230 500],sizet);
      SubSLR(cty,yi,rcp,sizei,1) = 1 + SubSLR(cty,yi,rcp,sizei,1);
      if isempty(csubs.OceanBay{inds(i)})
        armcost = InitCost.BackBay * lengthshore * (1 + OaMrate.BackBay*.30);
      else
        armcost = InitCost.OpenOcean * lengthshore * (1 + OaMrate.OpenOcean*.30);
      end
      if subCost(sizei) < armcost
        SubSLR(cty,yi,rcp,sizei,3) = 1 + SubSLR(cty,yi,rcp,sizei,3);
      else
        SubSLR(cty,yi,rcp,sizei,3) = armcost/subCost(sizei) + SubSLR(cty,yi,rcp,sizei,3);
      end
    end
    % storm surge
    css = SubSSdamage(ind,:,sceni);
    inds = find(sum(~isnan(css),2)>0);
    for i = 1:length(inds)
      sizet = csubs.MAX_VOLT(inds(i));
      sizei = findClosestInd([-999999 115 230 500],sizet);
      xx = css(inds(i),:); xx(isnan(xx)) = 0;
      xx1 = repmat(xx(2:end),10,1)./10; % results are decadal
      xx2 = xx1(:);
      SubStormSurge(cty,:,rcp,sizei,1) = bsxfun(@plus,xx2(7:end)', SubStormSurge(cty,:,rcp,sizei,1));
      % proactive armoring
      damsum = cumsum(xx2(7:end))*subCost(sizei);
      if isempty(csubs.OceanBay{inds(i)})
        armcost = InitCost.BackBay * lengthshore * (1 + OaMrate.BackBay*.30);
      else
        armcost = InitCost.OpenOcean * lengthshore * (1 + OaMrate.OpenOcean*.30);
      end
      protect = find(damsum > armcost,1);
      if ~isempty(protect)
        SubStormSurge(cty,1:protect,rcp,sizei,3) = SubStormSurge(cty,1:protect,rcp,sizei,1);
        SubStormSurge(cty,protect,rcp,sizei,3) = armcost/subCost(sizei)+SubStormSurge(cty,protect,rcp,sizei,1);
      else
        SubStormSurge(cty,:,rcp,sizei,3) = SubStormSurge(cty,:,rcp,sizei,1);
      end
    end
  end
end
end
SubSLR(:,:,:,:,2) = SubSLR(:,:,:,:,1);
SubStormSurge(:,:,:,:,2) = SubStormSurge(:,:,:,:,1);

% %-- process transformer lifespan so it includes a baseline
baseLife = nanmean(DistTransformerLossLife(:,1:num.yearsHist,1),2); % assume a 30-year lifespan
DistTransformerLossLife = bsxfun(@minus,DistTransformerLossLife,baseLife) + 1;

%-- substation lifespan
PowerTransLife = PowerTransLife1 ./ 48.26 + 1; % convert to years lost

%-- wood pole post-processing, convert into loss of life
D = 263; % Diameter for Class 5 pole
life = 32; % 32 years baseline (Morrel 2005) [although likely longer, Morrel 2016]
S = (D - poleDecayRate*life).^3 ./ (D^3); % strength fraction after end of life 
nodecay = S==1;
design = 0.6;
WoodPoleLifespan = design./S;
% account for higher treatment in certain regions (mostly florida)
baseLife = nanmean(WoodPoleLifespan(:,1:num.yearsHist,1),2);
BCi = baseLife > 1; % only correct when 
WoodPoleLifespan(BCi,:,:) = bsxfun(@rdivide,WoodPoleLifespan(BCi,:,:),baseLife(BCi));
WoodPoleLifespan(nodecay|WoodPoleLifespan<(32/50)) = 32/50; % assume a 50-year maximum life
poles = INFR.data(:,4,10,2,1,1);
baseLifeQC = sum((nanmean(WoodPoleLifespan(:,1:num.yearsHist,1),2) .* poles),1) ./ sum(poles);
% equates to about 40 year lifespan on average, in the baseline

%-- distribution capacity (smooth using lifespan of 30 years and always increasing)
xx1 = cat(2,zeros(num.cty,30,num.clims),DistTransformerCapFrac);
xx2 = cat(2,xx1,repmat(nanmean(xx1(:,end-9:end,:),2),[1 30 1]));
xx2(isnan(xx2)) = 0;
xx3 = nan(size(xx2));
sm = 30;
% mid-point smooth
prev = 0;
for y = 1:num.yearsFut+60
  y1 = max(y-14,1);
  y2 = min(y+15,size(xx2,2));
  xx3(:,y,:) = max(prev,mean(xx2(:,y1:y2,:),2)); % always increasing
  prev = xx3(:,y,:);
end
DistTransformerCapFrac = xx3(:,31:end-30,:);

%-- make capacity relative to max from history
TransLineCapfrac = cat(5,TransLineCapfrac,TransLineCapfracACSS,TransLineCapfracACCC);
TransLineCapfrac = bsxfun(@minus,TransLineCapfrac,TransLineCapfrac(:,20,1,:,1));
PowerTransCapfrac = bsxfun(@minus,PowerTransCapfrac,PowerTransCapfrac(:,20,1));
DistTransformerCapFrac = bsxfun(@minus,DistTransformerCapFrac,DistTransformerCapFrac(:,1,:));

save([home.output 'intermediate/SR_post.mat'],...
  'DistTransformerLossLife', 'PowerTransLife', 'WoodPoleLifespan', ...
  'PowerTransCapfrac', 'TransLineCapfrac', 'DistTransformerCapFrac')
