%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

% Post-process Adaptation

load([home.output 'intermediate/SR_post.mat'])

%% wood poles

L0 = 32; % design lifespan
Lm = 50; % maximum lifespan
baseLOL = nanmean(WoodPoleLifespan(:,1:num.yearsHist,1),2);
baseLife = L0./baseLOL;
xx1 = cat(2,repmat(baseLOL,[1 L0*2 num.clims]),WoodPoleLifespan);
xx2 = cat(2,xx1,repmat(nanmean(WoodPoleLifespan(:,end-9:end,:),2),[1 L0 1]));
xx2(isnan(xx2)) = 1;
xx3 = repmat(xx2,[1 1 1 4]);
xx4 = xx3;
protect = zeros(size(xx3)); % fraction protected
for y = L0*2+1:num.yearsFut+L0*2
  
  % set protection to preotection last year
%   protect(:,y,:,:) = protect(:,y-1,:,:);
  
  % loop over adaptation scenarios
  for ad = 1:3
    
    if ad==1
      % backward looking
      y1 = y-L0*2+1;
      y2 = y-L0+1;
      LOL = nanmean(xx3(:,y1:y2,:,1),2);
    elseif ad==2 % non-perfect foresight
      % forward looking using mean of GCMs
      LOL0 = repmat(nanmean(nanmean(xx3(:,y-L0+1:y,2:end,1),2),3),[1 1 13 1]); % GCM mean lookback
      LOL1 = repmat(nanmean(nanmean(xx3(:,y:y+L0,2:end,1),2),3),[1 1 13 1]); % GCM mean lookforward
      LOLa = nanmean(xx3(:,y-L0+1:y,:,1),2); % current LOL
      % adjust to start at current (only use projected change)
      LOLadj = LOL0 - LOL1; 
      LOL = LOLa + LOLadj;
%       LOL = repmat(nanmean(nanmean(xx3(:,y1:y2,2:end,1),2),3),[1 1 13 1]);
    elseif ad==3 % perfect foresight
      % forward looking with perfect foresight
      LOL = nanmean(xx3(:,y,:,1),2);
    end
    LOLmat(:,y,:,ad) = LOL;
  
  % determine design given either past or future life cycle
  L = squeeze( L0 * (1/LOL) );
  
  for clim = 2:num.clims
    
    ind = L(:,clim)<baseLife;
    
    if sum(ind)>0

    % update protection fraction
    protect1 = (L(:,clim)-baseLife) ./ (L(:,clim)-Lm); % fraction of protected
    protect1(isinf(protect1)|protect1>1|protect1<0) = 0;
%     protect(ind,y,clim,ad+1) = max(protect1(ind),protect(ind,y,clim,ad+1));
    protect(ind,y,clim,ad+1) = protect1(ind);
    
%     % QC
% %{
    Lmean = (L(ind,clim).*(1-protect1(ind)) + Lm*protect1(ind));
    check = sum((Lmean >= baseLife(ind)*1.0001) | (Lmean <= baseLife(ind)*.99999));
    if check>0
      keyboard
    end
%}
    
    % update lifespan
    Lnow = L0*1./xx3(:,y,clim,1);
    lifeNew = (Lnow.*(1-protect(:,y,clim,ad+1)) + Lm*protect(:,y,clim,ad+1));
    xx4(:,y,clim,ad+1) = L0./lifeNew; % new LOL
          
    % QC
    Lnow = L0./mean(xx3(:,y,clim,1),2);
    check = (Lnow.*(1-protect(:,y,clim,ad+1)) + Lm*protect(:,y,clim,ad+1));    
    if sum(check<baseLife*.99) && ad==3
      keyboard
    end
    
%     if ad>0 && y == num.yearsFut + L0
%       keyboard
%     end
    
    end
    
  end
  
  end
  
end
% xx4(xx4<.64) = 0.64;
% xx4(xx4>2.5) = 2.5;
WoodPoleLifespanAdapt.life = xx4(:,L0*2+1:end-L0,:,:);
% WoodPoleLifespanAdapt.life(:,:,:,5) = L0/Lm;
WoodPoleLifespanAdapt.upgrade = protect(:,L0*2+1:end-L0,:,:);
% WoodPoleLifespanAdapt.upgrade(:,:,:,5) = 1;

% QC
%{

poles = INFR.data(:,4,1,1,1,1);
poleLifeNat = squeeze(sum(bsxfun(@times,WoodPoleLifespanAdapt.life, poles),1)./ sum(poles,1));
poleUpNat = squeeze(sum(bsxfun(@times,WoodPoleLifespanAdapt.upgrade, poles),1)./ sum(poles,1));
poleDesign = squeeze(sum(bsxfun(@times,LOLmat, poles),1)./ sum(poles,1));
clim = 11;
figure(46), clf
subplot(2,1,1)
% data = (1-1./squeeze(poleLifeNat(:,clim,:)))*100;
% for i = 1:4
%   [datad(:,i), noise] = detrendMA2a(data(:,i),11);
% end
% datad = datad - datad(5);
data = squeeze(poleLifeNat(:,clim,:));
plot(S.key.years,data,'LineWidth',1.5)
datab = nan(4,3);
for ad = 1:4
  datab(:,ad) = mean(reshape(data(15:end,ad),20,[]),1);
end
% ylim([.9 inf])
xlim([S.key.years(1) S.key.years(end)])
legend(S.key.adapt,'Location','northwest')
title('Deterioration Rate (years)')
ylabel('Deterioration Rate (years)')
subplot(2,1,2)
plot(S.key.years,squeeze(poleUpNat(:,clim,:))*100,'LineWidth',1.5)
% legend(S.key.adapt)
title('Upgrades Built (%)')
ylabel('Upgrades Built (%)')
xlim([S.key.years(1) S.key.years(end)])
legend(S.key.adapt,'Location','northwest')

cty = 3e3; %215 313 356 357
clim = 3;
figure(45), clf
subplot(2,1,1)
plot(squeeze(WoodPoleLifespanAdapt.life(cty,:,clim,:))), legend(names.adapt)
title('Lifespan')
subplot(2,1,2)
plot(squeeze(WoodPoleLifespanAdapt.upgrade(cty,:,clim,:)))
legend(names.adapt)
title('Upgrade Fraction')

figure(45), clf
subplot(2,1,1)

plot(squeeze(WoodPoleLifespanAdapt.life(cty,:,clim,:))), legend(names.adapt)
title('Lifespan')
subplot(2,1,2)
plot(squeeze(WoodPoleLifespanAdapt.upgrade(cty,:,clim,:)))
legend(names.adapt)
title('Upgrade Fraction')

figure(45), clf
ad = 4;
col.devP = [makeColorMap([0.6 0 0], [1 0.5 0], [1 1 0.6], 5);
  makeColorMap([0.6 1 1], [0 0.5 1], [0 0 0.6], 5)];
mapdat1 = mean(WoodPoleLifespanAdapt.life(:,1:20,1,1),2);
mapdat2 = mean(mean(WoodPoleLifespanAdapt.life(:,end-20:end,2:2:end,ad),2),3);
mapdat = (mapdat2./mapdat1-1)*100;
mapPoly(mapdat1,'county_v2',...
                'colors',flipud(col.devP), 'linewidth', 0.02, 'linecolor', 'none', ...
                'colorbar', 1,  'colorbarPos', [0.2 0.16 0.6 0.03], ...
                'colorbar',0,...
                'colorlimits', [0.6 1.2], 'nanColor', [1 1 1], ...
                'inequalitySymb',1 ...
              );
mapPoly(mapdat,'county_v2',...
                'colors',flipud(col.devP), 'linewidth', 0.02, 'linecolor', 'none', ...
                'colorbar', 1,  'colorbarPos', [0.2 0.16 0.6 0.03], ...
                'colorbar',0,...
                'colorlimits', [-0.1 0.1], 'nanColor', [1 1 1], ...
                'inequalitySymb',1 ...
              );
%}

%% distribution transformers

L0 = 30;

% set no adaptation and perfect foresight
DistTransformerCapFrac(isnan(DistTransformerCapFrac)) = 0;
DistTransformerAdapt.capFrac = zeros([size(DistTransformerCapFrac) 4]);
DistTransformerAdapt.capFrac(:,:,2:end,4) = DistTransformerCapFrac(:,:,2:end);
DistTransformerAdapt.life = zeros([size(DistTransformerLossLife) 4]);
DistTransformerAdapt.life(:,:,1,1) = DistTransformerLossLife(:,:,1); % baseline
baseLife = nanmean(DistTransformerLossLife(:,1:20,1),2);
DistTransformerAdapt.life(:,:,2:end,1) = DistTransformerLossLife(:,:,2:end);
DistTransformerAdapt.life(:,:,2:end,4) = min(1,DistTransformerLossLife(:,:,2:end));

% life1 = cat(2,ones(num.cty,L0,num.clims),DistTransformerLossLife,repmat(nanmean(DistTransformerLossLife(:,end-9:end,:),2),[1 L0 1]));
cap1 = cat(2,zeros(num.cty,L0,num.clims),DistTransformerCapFrac,repmat(nanmean(DistTransformerCapFrac(:,end-9:end,:),2),[1 L0 1]));
cap1(isnan(cap1)) = 0;

% reactive (look back)
DistTransformerAdapt.capFrac(:,:,2:end,2) = min(DistTransformerCapFrac(:,:,2:end),cap1(:,1:num.yearsFut,2:end));

% practive (look forward)
capF0 = nanmean(cap1(:,L0/2+1:end-L0*3/2,2:end),3); % GCM mean current
capF = nanmean(cap1(:,L0+1:end-L0,2:end),3); % GCM mean projection
capA = cap1(:,L0/2+1:end-L0*3/2,2:end);% Actual current
DistTransformerAdapt.capFrac(:,:,2:end,3) = bsxfun(@plus,capA,capF-capF0);
for y = 2:num.yearsFut
  DistTransformerAdapt.capFrac(:,y,2:end,3) = max(DistTransformerAdapt.capFrac(:,y,2:end,3),DistTransformerAdapt.capFrac(:,y-1,2:end,3));
end

% calculate LOL based on the amount of capacity built
for ad = 2:3
  % fraction of capacity needed
  capDef = DistTransformerAdapt.capFrac(:,:,2:end,ad) ./ DistTransformerAdapt.capFrac(:,:,2:end,4);
  capDef(capDef>1) = 1;
  defAdj = bsxfun(@times,capDef,baseLife);
  DistTransformerAdapt.life(:,:,2:end,ad) = min(defAdj + (1-capDef).*DistTransformerLossLife(:,:,2:end),DistTransformerLossLife(:,:,2:end));
end

% QC
%{
cty = 215; %215 313 356 357
clim = 3;
figure(45), clf
subplot(2,1,1)
plot(squeeze(DistTransformerAdapt.life(cty,:,clim,:))), legend(names.adapt)
title('Loss of Life')
subplot(2,1,2)
plot(squeeze(DistTransformerAdapt.capFrac(cty,:,clim,:)))
legend(names.adapt)
title('Capacity Built')
%}

%% large transformers

L0 = 48.26;
L0i = 50; % integer used for indexing

% set no adaptation and perfect foresight
PowerTransCapfrac(isnan(PowerTransCapfrac)) = 0;
PowerTransAdapt.capFrac = zeros([size(PowerTransCapfrac) 4]);
PowerTransAdapt.capFrac(:,:,2:end,4) = PowerTransCapfrac(:,:,2:end);
PowerTransAdapt.life = zeros([size(PowerTransLife) 4]);
PowerTransAdapt.life(:,:,1,1) = PowerTransLife(:,:,1);
PowerTransAdapt.life(:,:,2:end,1) = PowerTransLife(:,:,2:end);
PowerTransAdapt.life(:,:,2:end,4) = min(1,PowerTransLife(:,:,2:end));

% life1 = cat(2,ones(num.cty,L0,num.clims),PowerTransLossLife,repmat(nanmean(PowerTransLossLife(:,end-9:end,:),2),[1 L0 1]));
cap1 = cat(2,zeros(num.cty,L0i,num.clims),PowerTransCapfrac,repmat(nanmean(PowerTransCapfrac(:,end-9:end,:),2),[1 L0i 1]));
cap1(isnan(cap1)) = 0;

% reactive (look back)
PowerTransAdapt.capFrac(:,:,2:end,2) = min(PowerTransCapfrac(:,:,2:end),cap1(:,1:num.yearsFut,2:end));

% practive (look forward)
capF0 = nanmean(cap1(:,L0i/2+1:end-L0i*3/2,2:end),3); % GCM mean current
capF = nanmean(cap1(:,L0i+1:end-L0i,2:end),3); % GCM mean projection
capA = cap1(:,L0i/2+1:end-L0i*3/2,2:end);% Actual current
PowerTransAdapt.capFrac(:,:,2:end,3) = bsxfun(@plus,capA,capF-capF0);
for y = 2:num.yearsFut
  PowerTransAdapt.capFrac(:,y,2:end,3) = max(PowerTransAdapt.capFrac(:,y,2:end,3),PowerTransAdapt.capFrac(:,y-1,2:end,3));
end

% calculate LOL based on the amount of capacity built
for ad = 2:3
  % fraction of capacity needed
  capDef = PowerTransAdapt.capFrac(:,:,2:end,ad) ./ PowerTransAdapt.capFrac(:,:,2:end,4);
  capDef(capDef>1) = 1;
  PowerTransAdapt.life(:,:,2:end,ad) = min(capDef*1 + (1-capDef).*PowerTransLife(:,:,2:end),PowerTransLife(:,:,2:end));
end

% QC
%{
cty = 215; %215 313 356 357
clim = 3;
figure(45), clf
subplot(2,1,1)
plot(squeeze(PowerTransAdapt.life(cty,:,clim,:))), legend(names.adapt)
title('Loss of Life')
subplot(2,1,2)
plot(squeeze(PowerTransAdapt.capFrac(cty,:,clim,:)))
legend(names.adapt)
title('Capacity Built')
%}

%% Power Lines and Heat

L0 = 10;
xx2 = cat(2,zeros(num.cty,L0,num.clims,num.volts,3),TransLineCapfrac);
xx3 = cat(2,xx2,repmat(nanmean(TransLineCapfrac(:,end-9:end,:,:,:),2),[1 L0 1 1 1]));
xx3(isnan(xx3)) = 0;
xx4 = zeros(size(xx3));
upgrade = zeros(size(xx4));
for y = L0:num.yearsFut+L0
  
  % loop over adaptation scenarios
  for ad = 1:3
    
    if ad==1
      % backward looking
      capDesign = xx3(:,y-L0+1,:,:,1);
    elseif ad==2 % non-perfect foresight
      % forward looking using mean of GCMs
      capDesign0 = repmat(nanmean(xx3(:,y,2:end,:,1),3),[1 1 13 1 1]); % GCM mean lookback
      capDesign1 = repmat(nanmean(xx3(:,y-L0+1,2:end,:,1),3),[1 1 13 1]); % GCM mean lookforward
      capDesigna = xx3(:,y-L0+1,:,:,1); % current LOL
      % adjust to start at current (only use projected change)
      capDesign = capDesigna + capDesign0 - capDesign1;
      capDesign = min(xx3(:,y,:,:,1),capDesign);
    elseif ad==3 % perfect foresight
      % forward looking with perfect foresight
      capDesign = xx3(:,y,:,:,1);
    end
    upgrade1 = capDesign./xx3(:,y,:,:,1);
    upgrade1(isnan(upgrade1)|isinf(upgrade1)) = 0;
    upgrade1(upgrade1>1) = 1;
  
  % determine design given either past or future
  
    xx4(:,y,:,:,ad) = (upgrade1*1.2/2 + (1-upgrade1)) .* xx3(:,y,:,:,1);
    upgrade(:,y,:,:,ad) = upgrade1;
  
  end
  
end
TransLineCapfracAdapt.cap = cat(5,TransLineCapfrac(:,:,:,:,1),xx4(:,L0+1:end-L0,:,:,:));

% QC
%{
cty = 3e3; %215 313 356 357
clim = 3;
figure(45), clf
subplot(2,1,1)
plot(squeeze(WoodPoleLifespanAdapt.life(cty,:,clim,:))), legend(names.adapt)
title('Lifespan')
subplot(2,1,2)
plot(squeeze(WoodPoleLifespanAdapt.upgrade(cty,:,clim,:)))
legend(names.adapt)
title('Upgrade Fraction')
%}

