%% Impacts and Costs

%% Step 1. Preallocate matrix
Costs = zeros(num.counties, num.years, num.climates, num.adapt, num.SRs, 'single');

%% Step 2. Run process
for sr = 1:num.SRs
  load([home.sr '\Output\MAT Files\SR Pieces_v3\' names.SRfiles{sr}], 'data');
  
  switch names.SRs{sr}
    case {'Trans Line Capacity'}
      data.cap(data.cap < 0) = 0;
      impact = squeeze(mean(data.cap, 4)); 
      infT = inf(:, :, :, 2, 2); %assumes "no policy" build out
        
      cost = mean(costs(4:8));   
      CumuCosts = cost*impact.*infT;  
      Costs(:, :, :, :, sr) = CumuCosts;
      Costs(:, 2:end, :, :, sr) = CumuCosts(:, 2:end, :, :) - CumuCosts(:, 1:num.years-1, :, :);
      
    case {'Distrib Line Capacity'}
      data.cap(data.cap < 0) = 0;
      impact = data.cap(:, :, :, 6, :);
      infT = inf(:, :, :, 3, 2); %assumes "no policy" build out
      
      cost = costs(3);
      CumuCosts = cost*impact.*infT;
      Costs(:, :, :, :, sr) = CumuCosts;
      Costs(:, 2:end, :, :, sr) = CumuCosts(:, 2:end, :, :) - CumuCosts(:, 1:num.years-1, :, :);
      
    case {'Wild Fire Repair'}
      % Make the GFDL dimension the average across the other GCMs
      tmp.r45 = mean(data(:, :, 2:2:end), 3);
      tmp.r85 = mean(data(:, :, 3:2:end), 3);
      
      impact = cat(3, data(:, :, 1:5), tmp.r45, tmp.r85,...
        data(:, :, 6:11));

      %Construct infrastructure vector
      tmp.inf = inf(:, :, :, 2, 2); %assumes "no policy" build out
      infT = bsxfun(@rdivide, tmp.inf, mean(tmp.inf(:, 1:10, 1), 2));
      
      %Costs
      cost = 1920000;  %$1.92 million per line mile for repair
      baseCosts = cost*mean(impact(:, 1:20, 1), 2);
      Costs(:, :, :, :, sr) = repmat(bsxfun(@minus, cost*infT.*impact, baseCosts),...
        [1 1 1 num.adapt 1]);
      
    case {'Tree Trimming'}
      % Make the GFDL dimension the average across the other GCMs
      tmp.r45 = mean(data(:, :, 2:2:end), 3);
      tmp.r85 = mean(data(:, :, 3:2:end), 3);
      
      impact = cat(3, data(:, :, 1:5), tmp.r45, tmp.r85,...
        data(:, :, 6:11));

      infT = inf(:, :, :, 3, 2); %assumes "no policy" build out

      baseCosts = bsxfun(@times, infT(:, :, 1), mean(impact(:, 1:20, 1), 2));
      Costs(:, :, :, :, sr) = repmat(bsxfun(@minus, infT.*impact, baseCosts),...
        [1 1 1 num.adapt 1]);
 
    case {'Substation SLR'}
      costSLR = permute(num.subRelocFrac*costSub, [1 3 4 2]); %(transformers per substation)*(cost/transformer)
      Costs(:, :, :, 1:3, sr) = squeeze(nansum(data(:, :, [1 1 2 1 2 1 2 1 2 1 2 1 2], :, :).*costSLR, 4));
      
    case {'Substation Storm Surge'}
      %infT = inf(:, :, :, 1, 2); %assumes "no policy" build out,this is substation dimension
      %tmp.baseVec = mean(infT(:, 1:10, 1), 2).*data;
      tmp.costSub = permute(costSub, [1 3 4 2]);
      Costs(:, :, :, 1:3, sr) = squeeze(nansum(data(:, :, [1 1 2 1 2 1 2 1 2 1 2 1 2], :, :).*tmp.costSub, 4));
      
    case {'Wood Pole Decay'}
      %lifespan impact 
      impact = data.life;  %units are number of years of aging
      infT = inf(:, :, :, 4, 2); %assumes "no policy" build out
      cost = costs(1)/life.woodPole; %annual baseline wood power pole depreciation
      tmp.lifeCosts = cost*infT.*(bsxfun(@minus, impact, nanmean(impact(:, 1:20, 1, 1), 2))); 
      
      %upgrade costs 
      impact = data.upgrade;
      CumuCosts = costPole*impact.*infT;
      tmp.upgradeCosts = CumuCosts;
      tmp.upgradeCosts(:, 2:end, :, :) = CumuCosts(:, 2:end, :, :) - CumuCosts(:, 1:num.years-1, :, :);
      
      %Net costs
      Costs(:, :, :, :, sr) = tmp.lifeCosts + tmp.upgradeCosts;
      
    case {'Trans Transformer Lifespan'}
      % Capacity
      impact = data.capFrac;
      infT = num.transPerSub*inf(:, :, :, 1, 2); %transformers per substation, assumes "no policy" build out   
      cost = costs(9); %cost/transformer
      CumuCosts = cost*impact.*infT;
      tmp.capCosts = CumuCosts;
      tmp.capCosts(:, 2:end, :, :) = CumuCosts(:, 2:end, :, :) - CumuCosts(:, 1:num.years-1, :, :);

      % Lifespan
      impact = data.life;  %units are number of years of aging
      cost = costs(9)/life.transTrans; %annual baseline transformer depreciation
      tmp.lifeCosts = cost*infT.*(impact - 1);
      
      % Total costs
      Costs(:, :, :, :, sr) = tmp.lifeCosts + tmp.capCosts;
      
    case {'Distrib Transfomer Lifespan'}
      % Capacity
      impact = data.capFrac;
      infT = inf(:, :, :, 5, 2); %transformers per substation, assumes "no policy" build out   
      cost = costs(2); %cost/transformer
      CumuCosts = cost*impact.*infT;
      tmp.capCosts = CumuCosts;
      tmp.capCosts(:, 2:end, :, :) = CumuCosts(:, 2:end, :, :) - CumuCosts(:, 1:num.years-1, :, :);

      % Lifespan
      impact = data.life;  %units are number of years of aging
      cost = costs(2)/life.distTrans; %annual baseline transformer depreciation
      tmp.lifeCosts = cost*infT.*(impact - 1);
      
      % Total costs
      Costs(:, :, :, :, sr) = tmp.lifeCosts + tmp.capCosts;
         
  end
end

%% Step 3. Create a state-level version of results
tmp.st = floor(names.counties/1000);
tmp.ind = unique(tmp.st);
tmp.ind(tmp.ind == 11) = [];  %remove fips 11, which does not exist in lower 48

% Calculate total infra value (NEED LIFESPAN TO ANNUALIZE)
tmp.costs = [costs(9)*num.transPerSub mean(costs(4:8)) costs(3) costs(1) costs(2)];
tmp.life = [life.transTrans life.transTrans life.distTrans life.woodPole life.distTrans];
tmp.value = inf(:, :, :, :, 2).*permute(tmp.costs./tmp.life, [4 3 1 2]);
tmp.val = squeeze(nansum(nanmean(nanmean(reshape(tmp.value(:, 75:end, 2:end, :),...
  num.counties, 20, 2, num.gcms, num.infrastructure), 5), 2), 4));

CostsSt = zeros(num.states, num.years, num.climates, num.adapt, num.SRs, 'single');
demCust2090 = zeros(num.states, 2);
infValAnnSt = zeros(num.states, num.rcps);
for st = 1:num.states
  ind = tmp.st == tmp.ind(st);
  CostsSt(st, :, :, :, :) = nansum(Costs(ind, :, :, :, :), 1);
  demCust2090(st, 1) = nansum(dem2090(ind));
  demCust2090(st, 2) = nansum(cust2090(ind));
  infValAnnSt(st, :) = nansum(tmp.val(ind, :), 1);
end


%% Step 4. Outputs to file
key.dims = {'counties', 'years', 'climates', 'adapt', 'SRs'};
key.SRs = names.SRs';
key.counties = names.counties;
key.years = names.years;
key.climates = names.climates;
key.adapt = names.adapt;

save([home.outputs '\MAT Files\CostsResults'], 'Costs', 'CostsSt', 'demCust2090', 'key');

clear sr impact infT data CumuCosts cost baseCosts a b ans


