%% Disclaimer
%{

The information in this document is currently being subjected to peer 
review. Mention of trade names or commercial products does not constitute 
endorsement or recommendation for use by the developers.

The code here must be used at the user's own risk. 

Neither Industrial Economics, Inc., nor the program authors can assume 
responsibility for model operation, output, interpretation or usage.

The creators of this program have used their best efforts in preparing this 
code. It is not absolutely guaranteed to be error free. The author/programmer 
makes no warrantees, expressed or implied, including without limitation 
warrantees of merchantability or fitness for any particular purpose. No 
liability is accepted in any event for any damages, including accidental or 
consequential damages, lost of profits, costs of lost data or programming 
materials, or otherwise in connection with or arising out of the use of 
this program.

%}

%%

%% Setup

%% Step 1. Directories
home.home = 'C:\MATLAB';
home.proj = [home.home '\02 Projects\EPA Grid Reliability II'];
home.inv = [home.proj '\04 Data and Analysis\01 Infrastructure Inventory'];
home.sr = [home.proj '\04 Data and Analysis\03 Stressor Response'];
home.outputs = [home.proj '\04 Data and Analysis\04 Economic\Output'];
home.graphics = [home.outputs '\Graphics'];

addpath(genpath([home.home '\01 Data\src']));

%% Step 2. Names and Numbers
load([home.inv '\Output\MAT Files\Infrastructure_Inventory'], 'data', 'key');
names.infDims = key.dims;
names.counties = key.counties;  
names.infrastructure = key.infrastructure; 
names.infYears = key.years;
names.policy = key.policy;
names.infModels = key.models;
names.rcps = {'RCP4.5', 'RCP8.5'};

load([home.sr '\Output\MAT Files\SR Pieces_v3\DistLineLightning'], 'key');
names.srDims = key.dims;
names.years = 2006:2099;
names.climates = key.climates;
names.gcms = key.gcms;
names.TransLineCapfracVolts = key.TransLineCapfracVolts;
names.units = key.units;
names.adapt = key.adapt;
names.slrStormDims = {'county', 'year', 'subSize', 'adapt'};

names.SRs = {'Trans Line Capacity', 'Distrib Line Capacity',...
  'Wild Fire Repair', 'Tree Trimming',...
  'Substation SLR', 'Substation Storm Surge', 'Wood Pole Decay',...
  'Trans Transformer Lifespan', 'Distrib Transfomer Lifespan'};

names.SRfiles = {'TransLineCapfracAdapt', 'TransLineCapfracAdapt',...
  'wfLineMilesBurned', 'TreeTrimCosts', 'SubSLR', 'SubStormSurge',...
  'WoodPoleLifespanAdapt', 'PowerTransAdapt', 'DistTransformerAdapt'};

names.SRgraphs = {'TLineCap', 'DLineCap', 'wfRepair',...
  'TreeTrim', 'SubSLR', 'SubStorm', 'WoodPole', 'TTransLife', 'DTransLife'};

%% Step 3. Numbers
num.counties = length(names.counties);
num.states = 48;
num.infrastructure = length(names.infrastructure);
num.infYears = length(names.infYears);
num.policy = length(names.policy);
num.infModels = length(names.infModels);
num.rcps = length(names.rcps);
num.years = length(names.years);
num.climates = length(names.climates);
num.gcms = length(names.gcms);
num.TransLineCapfracVolts = length(names.TransLineCapfracVolts);
num.SRs = length(names.SRs);
num.adapt = length(names.adapt);

%% Step 4. Key Assumptions
num.transPerSub = 2; %Average of 2 transformers per substation (Chas 7/5/2018 email, follow up)
num.subRelocFrac = 0.75; %75% of substation cost incurred to relocate under SLR scenario
life.transTrans = 48.26; %transmission transfomer life is 48.26 years
life.distTrans = 30; %distribution transformer life is 30 years
life.woodPole = 32; %average lifespan of woodpole is 32 years

%% Step 5. Import unit cost data
file = [home.proj '\04 Data and Analysis\04 Economic\Input\Data Files\Costing\Replacement Costs Infrastructure_Updated.xlsx'];
costs = xlsread(file, 'National Level', 'B3:B11');
[~, names.infCostsNames] = xlsread(file, 'National Level', 'A3:A11');
[~, names.infCostsUnits] = xlsread(file, 'National Level', 'C3:C11');

costSub = 1e6*[10 10 20 50]; %no data, small, medium, large (email from Chas 7/15/18)
costPole = 500; %$500/pole upgrade from 7/22 email from Chas

demCust2015 = xlsread([home.inv '\Input\Data Files\Combined_Demand_Data.xlsx'],...
  'FullDemandData', 'I4:J3112');
cust2090 = xlsread([home.inv '\Input\Data Files\Sales and Customers Expansion 2050 and 2090.xlsx'],...
  'Customers', 'I5:I3113');
dem2090 = xlsread([home.inv '\Input\Data Files\Sales and Customers Expansion 2050 and 2090.xlsx'],...
  'Sales', 'P5:P3113');


%% Step 6. Make infrastructure inventory consistent dimensions
inf = reshape(permute(data(:, :, 1:94, :, [7 1 2 6 3 4 5], :), [1 3 6 5 2 4]),...
  num.counties, num.years, [], num.infrastructure, num.policy);
inf(:, :, 2, :, :) = [];

clear data file key
